package cn.estsh.i3plus.pojo.wms.sqlpack;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.WmsEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.base.tool.HqlPack;
import cn.estsh.i3plus.pojo.wms.bean.*;
import cn.estsh.i3plus.pojo.wms.engine.script.EngineScriptPersistence;
import com.alibaba.fastjson.JSONObject;
import com.google.common.base.Strings;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @Description : 仓库管理对象封装
 * @Reference :
 * @Author : silliter.yuan
 * @CreateDate : 2018-10-31 10:45
 * @Modify:
 **/
public class WmsHqlPack {

    public static String packInParams(String colnumName, String[] params) {
        StringBuffer sb = new StringBuffer();
        HqlPack.getInPackString(String.join(",", params), colnumName, sb);
        HqlPack.getNumEqualPack(WmsEnumUtil.IS_PART.IS_ADJUST.getValue(), "snControl", sb);
        return sb.toString();
    }

    /**
     * 封装公用查询参数
     * @param bean   实体对象
     * @param hqlStr 查询语句
     * @return 封装完成的查询语句
     */
    public static DdlPackBean getStringBuilderPack(BaseBean bean, DdlPackBean hqlStr) {

        // 判断工厂代码是否为空
        if (StringUtils.isNotBlank(bean.getOrganizeCode())) {
            DdlPreparedPack.getStringEqualPack(bean.getOrganizeCode(), "organizeCode", hqlStr);
        }

        // 封装有效状态和删除状态
        DdlPreparedPack.getNumEqualPack(bean.getIsValid(), "isValid", hqlStr);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", hqlStr);

        return hqlStr;
    }

    /**
     * 封装公用查询参数
     *
     * @param bean   实体对象
     * @param hqlStr 查询语句
     * @return 封装完成的查询语句
     */
    public static String getStringBuilderPack(BaseBean bean, StringBuffer hqlStr) {

        // 判断工厂代码是否为空
        if (StringUtils.isNotBlank(bean.getOrganizeCode())) {
            HqlPack.getStringEqualPack(bean.getOrganizeCode(), "organizeCode", hqlStr);
        }

        // 封装有效状态和删除状态
        HqlPack.getNumEqualPack(bean.getIsValid(), "isValid", hqlStr);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", hqlStr);

        return hqlStr.toString();
    }

    /**
     * PO订单明细表 分页查询
     *
     * @param wmsPOMasterDetails
     * @return
     */
    public static String packHqlWmsPOMasterDetails(WmsPOMasterDetails wmsPOMasterDetails) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsPOMasterDetails.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsPOMasterDetails.getPartNo(), "partNo", result);
        HqlPack.getStringRightLikerPack(wmsPOMasterDetails.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getStringRightLikerPack(wmsPOMasterDetails.getPlanTime(), "planTime", result);
        HqlPack.getStringRightLikerPack(wmsPOMasterDetails.getPlanDate(), "planDate", result);

        getStringBuilderPack(wmsPOMasterDetails, result);

        return result.toString();
    }

    /**
     * 库存移动单详情查询封装
     *
     * @param wmsDocMovementDetails
     * @return
     */
    public static String packWmsDocMovementDetails(WmsDocMovementDetails wmsDocMovementDetails) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsDocMovementDetails.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsDocMovementDetails.getItemStatus(), "itemStatus", result);
        getStringBuilderPack(wmsDocMovementDetails, result);

        return result.toString();
    }

    /**
     * 查询任务合并的移库单明细 查询条件封装
     *
     * @param colName
     * @param orderNos
     * @return
     */
    public static DdlPackBean packWmsOrderDetailsByOrderNos(String colName, List<String> orderNos) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getInPack(orderNos, "orderNo", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", packBean);
        DdlPreparedPack.getOrderByPack(
                new Object[]{CommonEnumUtil.ASC_OR_DESC.DESC.getValue(), CommonEnumUtil.ASC_OR_DESC.DESC.getValue()},
                new String[]{colName, "orderNo"}, packBean);
        return packBean;
    }

    /**
     * 库存移动单查询封装
     *
     * @param wmsDocMovementMaster
     * @return
     */
    public static String packWmsDocMovementMaster(WmsDocMovementMaster wmsDocMovementMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringRightLikerPack(wmsDocMovementMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsDocMovementMaster.getMoveType(), "moveType", result);
        HqlPack.getNumEqualPack(wmsDocMovementMaster.getBusiType(), "busiType", result);
        HqlPack.getStringLikerPack(wmsDocMovementMaster.getCustNo(), "custNo", result);

        getStringBuilderPack(wmsDocMovementMaster, result);

        return result.toString();
    }

    /**
     * PO订单主表信息 分页查询
     *
     * @param wmsPOMaster
     * @return
     */
    public static String packHqlWmsPOMaster(WmsPOMaster wmsPOMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsPOMaster.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getPoType(), "poType", result);
        HqlPack.getNumEqualPack(wmsPOMaster.getPoStatus(), "poStatus", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getIsAsn(), "isAsn", result);

        getStringBuilderPack(wmsPOMaster, result);

        return result.toString();
    }

    /**
     * PO订单主表信息 分页查询(散件)
     *
     * @param wmsPOMaster
     * @return
     */
    public static String packHqlWmsPOMasterPart(WmsPOMaster wmsPOMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getInPack(String.join(",", WmsEnumUtil.MASTER_ORDER_STATUS.CREATE.getValue() + "",
                WmsEnumUtil.MASTER_ORDER_STATUS.RECEIPT.getValue() + ""), "poStatus", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue(), "isPart", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getPoType(), "poType", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsPOMaster.getIsAsn(), "isAsn", result);

        getStringBuilderPack(wmsPOMaster, result);

        return result.toString();
    }

    /**
     * 物流路线子表查询条件封装
     *
     * @param routingCode
     * @return
     */
    public static String packHqlWmsRoutingChildren(String routingCode) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(routingCode, "routingCode", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(),
                "isDeleted", result);

        return result.toString();
    }


    /**
     * 物流路线主表查询条件封装
     *
     * @param wmsRoutingMaster
     * @return
     */
    public static String packHqlWmsRoutingMaster(WmsRoutingMaster wmsRoutingMaster) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringLikerPack(wmsRoutingMaster.getRoutingCode(), "routingCode", result);
        HqlPack.getStringLikerPack(wmsRoutingMaster.getRoutingName(), "routingName", result);

        getStringBuilderPack(wmsRoutingMaster, result);

        return result.toString();
    }

    /**
     * 物料查询条件封装
     *
     * @param wmsPart
     * @return
     */
    public static String packHqlWmsPart(WmsPart wmsPart) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(wmsPart.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsPart.getPartName(), "partName", result);
        HqlPack.getStringLikerPack(wmsPart.getPartSpec(), "partSpec", result);
        HqlPack.getStringLikerPack(wmsPart.getPartType(), "partType", result);

        getStringBuilderPack(wmsPart, result);

        return result.toString();
    }

    /**
     * 抽点比例信息 分页查询
     *
     * @param wmsIbCheckPlan
     * @return
     */
    public static String packHqlWmsIbCheckPlan(WmsIbCheckPlan wmsIbCheckPlan) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsIbCheckPlan.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsIbCheckPlan.getPartNameRdd(), "partNameRdd", result);
        getStringBuilderPack(wmsIbCheckPlan, result);

        if (wmsIbCheckPlan.getStartDateStart() != null || wmsIbCheckPlan.getStartDateEnd() != null) {
            HqlPack.timeBuilder(wmsIbCheckPlan.getStartDateStart(), wmsIbCheckPlan.getStartDateEnd(), "startDate", result, false);
        }
        if (wmsIbCheckPlan.getEndDateStart() != null || wmsIbCheckPlan.getEndDateEnd() != null) {
            HqlPack.timeBuilder(wmsIbCheckPlan.getEndDateStart(), wmsIbCheckPlan.getEndDateEnd(), "endDate", result, false);
        }

        return result.toString();
    }

    /**
     * 库位物料信息 分页查询
     *
     * @param wmsLocatePart
     * @return
     */
    public static String packHqlWmsLocatePart(WmsLocatePart wmsLocatePart) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsLocatePart.getLocateNo(), "locateNo", result);
        HqlPack.getStringLikerPack(wmsLocatePart.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsLocatePart.getPartNameRdd(), "partNameRdd", result);

        getStringBuilderPack(wmsLocatePart, result);

        return result.toString();
    }

    /**
     * 库位信息 分页查询
     *
     * @param wmsLocate
     * @return
     */
    public static DdlPackBean packHqlWmsLocates(WmsLocate wmsLocate) {
        //查询参数封装
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getStringEqualPack(wmsLocate.getLocateNo(), "locateNo", result);
        DdlPreparedPack.getStringEqualPack(wmsLocate.getLocateName(), "locateName", result);
        DdlPreparedPack.getNumEqualPack(wmsLocate.getLocateType(), "locateType", result);
        DdlPreparedPack.getStringEqualPack(wmsLocate.getWhNo(), "whNo", result);
        DdlPreparedPack.getStringEqualPack(wmsLocate.getZoneNo(), "zoneNo", result);
        DdlPreparedPack.getNumEqualPack(wmsLocate.getStatus(), "status", result);

        getStringBuilderPack(wmsLocate, result);

        return result;
    }

    /**
     * 根据类型查询库位分页
     *
     * @param wmsLocate
     * @return
     */
    public static String packHqlWmsLocatesByType(WmsLocate wmsLocate) {
        StringBuffer result = new StringBuffer();
        //查询参数封装
        HqlPack.getNumEqualPack(wmsLocate.getLocateType(), "locateType", result);
        getStringBuilderPack(wmsLocate, result);
        return result.toString();
    }

    /**
     * 交易类型信息 分页查询
     *
     * @param wmsTransType
     * @return
     */
    public static DdlPackBean packHqlWmsTransType(WmsTransType wmsTransType) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getStringEqualPack(wmsTransType.getTransTypeCode(), "transTypeCode", result);
        DdlPreparedPack.getStringLikerPack(wmsTransType.getTransTypeName(), "transTypeName", result);
        DdlPreparedPack.getNumEqualPack(wmsTransType.getAgId(), "agId", result);

        getStringBuilderPack(wmsTransType, result);

        return result;
    }

    /**
     * 库存交易记录信息 分页查询
     *
     * @param wmsTrans
     * @return
     */
    public static String packHqlWmsTrans(WmsTrans wmsTrans) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsTrans.getTransCode(), "transCode", result);
        HqlPack.getStringEqualPack(wmsTrans.getSn(), "sn", result);
        HqlPack.timeBuilder(wmsTrans.getCreateDatetime(), null, "createDatetime", result, true);

        getStringBuilderPack(wmsTrans, result);

        return result.toString();
    }

    /**
     * 仓库分页查询条件
     *
     * @param wareHouse
     * @return
     */
    public static String packHqlWareHouse(WareHouse wareHouse) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(wareHouse.getAddress(), "address", result);
        HqlPack.getStringLikerPack(wareHouse.getCode(), "code", result);
        HqlPack.getStringLikerPack(wareHouse.getName(), "name", result);

        getStringBuilderPack(wareHouse, result);

        return result.toString();
    }

    /**
     * 供应商分页查询
     *
     * @param basVendor
     * @return
     */
    public static String packHqlBasVendor(BasVendor basVendor) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(basVendor.getVendorNo(), "vendorNo", result);
        HqlPack.getStringLikerPack(basVendor.getVendorName(), "vendorName", result);
        HqlPack.getStringLikerPack(basVendor.getVendorOwner(), "vendorOwner", result);
        HqlPack.getStringLikerPack(basVendor.getVendorDesc(), "vendorDesc", result);
        HqlPack.getStringLikerPack(basVendor.getVendorAddr(), "vendorAddr", result);
        HqlPack.getStringLikerPack(basVendor.getVendorEmail(), "vendorEmail", result);
        HqlPack.getNumEqualPack(basVendor.getIsAsn(), "isAsn", result);

        getStringBuilderPack(basVendor, result);

        return result.toString();
    }

    /**
     * 作业类型分页查询
     *
     * @param wmsOpType
     * @return
     */
    public static String packHqlWmsOpType(WmsOpType wmsOpType) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsOpType.getOpTypeCode(), "opTypeCode", result);
        HqlPack.getStringLikerPack(wmsOpType.getOpTypeName(), "opTypeName", result);
        HqlPack.getNumEqualPack(wmsOpType.getSeq(), "seq", result);

        getStringBuilderPack(wmsOpType, result);

        return result.toString();
    }

    /**
     * 仓库唯一性校验查询条件【用于添加和修改】
     *
     * @param wareHouse
     * @return
     */
    public static String packHqlWareHouseUnique(WareHouse wareHouse) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wareHouse.getName(), "name", result);
        HqlPack.getStringEqualPack(wareHouse.getCode(), "code", result);
        HqlPack.getNumNOEqualPack(wareHouse.getId(), "id", result);

        getStringBuilderPack(wareHouse, result);

        return result.toString();
    }

    /**
     * 供应商唯一性校验查询条件【用于添加和修改】
     *
     * @param basVendor
     * @return
     */
    public static String packHqlBasVendorUnique(BasVendor basVendor) {
        StringBuffer result = new StringBuffer();

        HqlPack.getNumNOEqualPack(basVendor.getId(), "id", result);
        HqlPack.getStringEqualPack(basVendor.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(basVendor.getVendorName(), "vendorName", result);
        HqlPack.getStringEqualPack(basVendor.getVendorDesc(), "vendorDesc", result);

        getStringBuilderPack(basVendor, result);

        return result.toString();
    }

    public static String packHqlWmsOpTypeUnique(WmsOpType wmsOpType) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsOpType.getOpTypeCode(), "opTypeCode", result);
        HqlPack.getStringLikerPack(wmsOpType.getOpTypeName(), "opTypeName", result);

        getStringBuilderPack(wmsOpType, result);

        return result.toString();
    }

    /**
     * 查询满足处理周期的作业类型 查询条件封装
     *
     * @param wmsOpType
     * @return
     */
    public static String packHqlWmsOpTypeTime(WmsOpType wmsOpType) {
        StringBuffer result = new StringBuffer();

        getStringBuilderPack(wmsOpType, result);
        result.append(" and isnull(model.lastTransTime) or timestampdiff(Minute,nvl(model.lastTransTime,'2000'),now()) >= model.cycleMins");
        return result.toString();
    }

    /**
     * 作业任务数据来源 查询条件封装
     *
     * @param wmsTaskSrc
     * @return
     */
    public static String packHqlWmsTaskSrc(WmsTaskSrc wmsTaskSrc) {
        StringBuffer result = new StringBuffer();

        //作业类型代码
        HqlPack.getStringLikerPack(wmsTaskSrc.getOpTypeCode(), "opTypeCode", result);

        getStringBuilderPack(wmsTaskSrc, result);

        return result.toString();
    }

    /**
     * 存储区信息 查询条件封装
     *
     * @param wmsZones
     * @return
     */
    public static String packHqlWmsZones(WmsZones wmsZones) {
        StringBuffer result = new StringBuffer();

        //仓库代码
        HqlPack.getStringLikerPack(wmsZones.getWhNo(), "whNo", result);
        //库存地代码
        HqlPack.getStringLikerPack(wmsZones.getAreaNo(), "areaNo", result);
        //存储区代码
        HqlPack.getStringLikerPack(wmsZones.getZoneNo(), "zoneNo", result);
        //存储区名称
        HqlPack.getStringLikerPack(wmsZones.getZoneName(), "zoneName", result);

        getStringBuilderPack(wmsZones, result);

        return result.toString();
    }

    /**
     * 客户信息 查询条件封装
     *
     * @param basCustomer
     * @return
     */
    public static String packHqlBasCustomer(BasCustomer basCustomer) {
        StringBuffer result = new StringBuffer();

        //客户编号
        HqlPack.getStringEqualPack(basCustomer.getCustNo(), "custNo", result);
        //客户简称
        HqlPack.getStringLikerPack(basCustomer.getCustName(), "custName", result);
        //客户全称
        HqlPack.getStringLikerPack(basCustomer.getCustDesc(), "custDesc", result);

        getStringBuilderPack(basCustomer, result);

        return result.toString();
    }

    /**
     * 客户发往地信息 查询条件封装
     *
     * @param wmsShippingFlag
     * @return
     */
    public static String packHqlWmsShippingFlag(WmsShippingFlag wmsShippingFlag) {
        StringBuffer result = new StringBuffer();

        //供应商编号
        HqlPack.getStringEqualPack(wmsShippingFlag.getFlagNo(), "flagNo", result);
        //供应商简称
        HqlPack.getStringLikerPack(wmsShippingFlag.getFlagName(), "flagName", result);
        //供应商全称
        HqlPack.getStringLikerPack(wmsShippingFlag.getFlagDesc(), "flagDesc", result);

        getStringBuilderPack(wmsShippingFlag, result);

        return result.toString();
    }

    /**
     * ASN订单分页查询条件
     *
     * @param wmsASNMaster
     * @return
     */
    public static String packHqlWmsASNMaster(WmsASNMaster wmsASNMaster) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringRightLikerPack(wmsASNMaster.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getAsnType(), "asnType", result);
        HqlPack.getNumEqualPack(wmsASNMaster.getAsnStatus(), "asnStatus", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getVersion(), "version", result);
        HqlPack.getStringLikerPack(wmsASNMaster.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsASNMaster.getPoNo(), "poNo", result);

        getStringBuilderPack(wmsASNMaster, result);

        return result.toString();
    }

    /**
     * 产品发运信息 查询条件封装
     *
     * @param wmsShopping
     * @return
     */
    public static String packHqlWmsShipping(WmsShopping wmsShopping) {
        StringBuffer result = new StringBuffer();

        //发运单号
        HqlPack.getStringLikerPack(wmsShopping.getOrderNo(), "orderNo", result);
        //客户编码
        HqlPack.getStringEqualPack(wmsShopping.getCustNo(), "custNo", result);
        //物料编码
        HqlPack.getStringEqualPack(wmsShopping.getPartNo(), "partNo", result);
        //条码
        HqlPack.getStringEqualPack(wmsShopping.getSn(), "sn", result);
        //发运状态
        HqlPack.getNumEqualPack(wmsShopping.getOrderStatus(), "orderStatus", result);
        //特殊发货标志
        HqlPack.getStringEqualPack(wmsShopping.getShippingFlag(), "shippingFlag", result);

        getStringBuilderPack(wmsShopping, result);

        return result.toString();
    }

    /**
     * 抽点记录信息 查询条件封装
     *
     * @param wmsCheckFactRecord
     * @return
     */
    public static String packHqlWmsCheckFactRecord(WmsCheckFactRecord wmsCheckFactRecord) {
        StringBuffer result = new StringBuffer();

        //采购单号
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getPoNo(), "poNo", result);
        //ASN单号
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getAsnNo(), "asnNo", result);
        //条码
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getSn(), "getSn", result);
        //物料编码
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getPartNo(), "partNo", result);
        //供应商编号
        HqlPack.getStringEqualPack(wmsCheckFactRecord.getVendorNo(), "vendorNo", result);

        getStringBuilderPack(wmsCheckFactRecord, result);

        return result.toString();
    }

    public static String packHqlWmsASNMasterDetails(WmsASNMasterDetails wmsASNMasterDetails) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsASNMasterDetails.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsASNMasterDetails.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getNumEqualPack(wmsASNMasterDetails.getQty(), "qty", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPoItem(), "poItem", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getUnit(), "unit", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPlanDate(), "planDate", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPlanTime(), "planTime", result);
        HqlPack.getNumEqualPack(wmsASNMasterDetails.getItemStatus(), "itemStatus", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getPackAge(), "packAge", result);
        HqlPack.getNumEqualPack(wmsASNMasterDetails.getIsFree(), "isFree", result);
        HqlPack.getStringLikerPack(wmsASNMasterDetails.getDock(), "dock", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getSnOneBarCode(), "snOneBarCode", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getSnTwoBarCode(), "snTwoBarCode", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getGroupNo(), "groupNo", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getErpAreaNo(), "erpAreaNo", result);
        HqlPack.getStringEqualPack(wmsASNMasterDetails.getVendorLotNo(), "vendorLotNo", result);

        getStringBuilderPack(wmsASNMasterDetails, result);

        return result.toString();
    }

    /**
     * 产品入库信息 条件封装
     *
     * @param wmsFGInStock
     * @return
     */
    public static String packHqlWmsFGInStock(WmsFGInStock wmsFGInStock) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsFGInStock.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getWoNo(), "woNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsFGInStock.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getNumEqualPackDouble(wmsFGInStock.getQty(), "qty", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getUnit(), "unit", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getSn(), "sn", result);
        HqlPack.getNumEqualPack(wmsFGInStock.getOrderStatus(), "orderStatus", result);
        HqlPack.getStringLikerPack(wmsFGInStock.getReMark(), "reMark", result);
        HqlPack.getStringLikerPack(wmsFGInStock.getSrc(), "src", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getErpAreaNo(), "erpWhno", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getLineNo(), "lineNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getCustNo(), "custNo", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getShippingFlag(), "shippingFlag", result);
        HqlPack.getStringEqualPack(wmsFGInStock.getMfgLogNo(), "mfgLogNo", result);

        getStringBuilderPack(wmsFGInStock, result);

        return result.toString();
    }

    /**
     * 作业任务信息条件封装
     *
     * @param wmsTaskInfo
     * @return
     */
    public static String packHqlWmsTaskInfo(WmsTaskInfo wmsTaskInfo) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringLikerPack(wmsTaskInfo.getMoveNo(), "moveNo", result);
        HqlPack.getStringLikerPack(wmsTaskInfo.getOrderNo(), "orderNo", result);
        HqlPack.getStringLikerPack(wmsTaskInfo.getUserNo(), "userNo", result);
        HqlPack.getStringLikerPack(wmsTaskInfo.getOpTypeCode(), "opTypeCode", result);
        HqlPack.getStringLikerPack(wmsTaskInfo.getRemark(), "remark", result);
        HqlPack.getNumEqualPack(wmsTaskInfo.getTaskStatus(), "taskStatus", result);

        getStringBuilderPack(wmsTaskInfo, result);

        return result.toString();
    }

    /**
     * 根据条件查询打印机队列信息封装类
     *
     * @param wmsSnPrint 打印机队列信息
     * @return 打印机队列信息
     */
    public static String packHqlWmsSnPrint(WmsSnPrint wmsSnPrint) {
        StringBuffer result = new StringBuffer();

        // 来源单据类型
        HqlPack.getStringEqualPack(wmsSnPrint.getRefType(), "refType", result);
        // 来源单据号
        HqlPack.getStringEqualPack(wmsSnPrint.getRefNo(), "refNo", result);
        // 打印机
        HqlPack.getStringEqualPack(wmsSnPrint.getPrinter(), "printer", result);
        // 打印机状态
        HqlPack.getNumEqualPack(wmsSnPrint.getPrintStatus(), "printStatus", result);

        getStringBuilderPack(wmsSnPrint, result);

        return result.toString();
    }

    /**
     * 盘点库位 条件封装
     *
     * @param wmsCSLocate
     * @return
     */
    public static String packHqlWmsCSLocate(WmsCSLocate wmsCSLocate) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsCSLocate.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsCSLocate.getLocateNo(), ";locateNo", result);

        getStringBuilderPack(wmsCSLocate, result);

        return result.toString();
    }

    /**
     * 盘点物料 条件封装
     *
     * @param wmsCSPart
     * @return
     */
    public static String packHqlWmsCSPart(WmsCSPart wmsCSPart) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsCSPart.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsCSPart.getPartNo(), "partNo", result);
        HqlPack.getNumEqualPack(wmsCSPart.getIsAdjust(), "isAdjust", result);
        HqlPack.getStringLikerPack(wmsCSPart.getPartNameRdd(), "partNameRdd", result);

        getStringBuilderPack(wmsCSPart, result);

        return result.toString();
    }

    /**
     * 盘点存储区 条件封装
     *
     * @param wmsCSZone
     * @return
     */
    public static String packHqlWmsCSZone(WmsCSZone wmsCSZone) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsCSZone.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsCSZone.getZoneNo(), "zoneNo", result);

        getStringBuilderPack(wmsCSZone, result);

        return result.toString();
    }

    /**
     * 根据条件查询责任区分配信息封装类
     *
     * @param wmsAreaOwner 责任区分配信息
     * @return 责任区分配信息
     */
    public static String packHqlWmsAreaOwner(WmsAreaOwner wmsAreaOwner) {
        StringBuffer result = new StringBuffer();

        // 仓库代码
        HqlPack.getStringEqualPack(wmsAreaOwner.getWhNo(), "whNo", result);
        // 来源单据号
        HqlPack.getStringEqualPack(wmsAreaOwner.getZoneNo(), "zoneNo", result);
        // 供应商编码
        HqlPack.getStringEqualPack(wmsAreaOwner.getVendorNo(), "vendorNo", result);
        // 物料编码
        HqlPack.getStringEqualPack(wmsAreaOwner.getPartNo(), "partNo", result);
        // 负责人
        HqlPack.getStringEqualPack(wmsAreaOwner.getOwnerUserNo(), "ownerUserNo", result);
        // 是否预分配
        HqlPack.getNumEqualPack(wmsAreaOwner.getIsPreAssign(), "isPreAssign", result);

        getStringBuilderPack(wmsAreaOwner, result);

        return result.toString();
    }

    /**
     * 根据条件查询责任区分配信息封装类
     *
     * @param wmsTempOrderLock 责任区分配信息
     * @return 责任区分配信息
     */
    public static String packHqlWmsTempOrderLock(WmsTempOrderLock wmsTempOrderLock) {
        StringBuffer result = new StringBuffer();

        // 订单号
        HqlPack.getStringLikerPack(wmsTempOrderLock.getOrderNo(), "orderNo", result);
        // 业务类型
        HqlPack.getNumEqualPack(wmsTempOrderLock.getBizType(), "bizType", result);

        // 物料代码
        HqlPack.getStringEqualPack(wmsTempOrderLock.getPartNo(), "partNo", result);

        getStringBuilderPack(wmsTempOrderLock, result);

        return result.toString();
    }

    /**
     * 业务：库存条码查询封装
     *
     * @param wmsStockSn
     * @return
     */
    public static String packWmsStockSn(WmsStockSn wmsStockSn) {
        StringBuffer result = new StringBuffer();
        //查询参数封装
        HqlPack.getStringEqualPack(wmsStockSn.getLocateNo(), "locateNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getSn(), "sn", result);
        HqlPack.getStringEqualPack(wmsStockSn.getRefSrc(), "refSrc", result);
        HqlPack.getNumEqualPack(wmsStockSn.getPrinted(), "printed", result);
        getStringBuilderPack(wmsStockSn, result);

        return result.toString();
    }

    /**
     * 业务：库存查询封装
     *
     * @param wmsStockQuan
     * @return
     */
    public static String packWmsStockQuan(WmsStockQuan wmsStockQuan) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsStockQuan.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getLocateNo(), "locateNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getCustNo(), "custNo", result);

        getStringBuilderPack(wmsStockQuan, result);

        return result.toString();
    }

    /**
     * 业务：库存交易条码查询封装(根据交易编码查询所有未删除的)
     *
     * @param tranNo
     * @return
     */
    public static String packWmsTransSn(String tranNo) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(tranNo, "transNo", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue(), "isDeleted", result);

        return result.toString();
    }

    /**
     * 业务：库存交易查询封装
     *
     * @param wmsTransQuan
     * @return
     */
    public static String packWmsTransQuan(WmsTransQuan wmsTransQuan) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsTransQuan.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getMoveNo(), "moveNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsTransQuan.getLocateNo(), "locateNo", result);

        getStringBuilderPack(wmsTransQuan, result);

        return result.toString();
    }

    /**
     * 业务：物料包装查询封装
     *
     * @param wmsPackage
     * @return
     */
    public static String packWmsPackAge(WmsPackage wmsPackage) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsPackage.getPackageNo(), "packageNo", result);
        HqlPack.getStringEqualPack(wmsPackage.getParentPackageNo(), "parentPackageNo", result);
        HqlPack.getNumEqualPack(wmsPackage.getPackTypeId(), "packTypeId", result);

        getStringBuilderPack(wmsPackage, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单主表唯一性查询
     *
     * @param wmsMoveMaster
     * @return
     */
    public static String packWmsMoveMasterUnique(WmsMoveMaster wmsMoveMaster) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumNOEqualPack(wmsMoveMaster.getId(), "id", result);
        HqlPack.getNumEqualPack(wmsMoveMaster.getOrderStatus(), "orderStatus", result);

        getStringBuilderPack(wmsMoveMaster, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单主表分页查询
     *
     * @param wmsMoveMaster
     * @return
     */
    public static String packHqlWmsMoveMaster(WmsMoveMaster wmsMoveMaster) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsMoveMaster.getOrderStatus(), "orderStatus", result);
        HqlPack.getStringEqualPack(wmsMoveMaster.getTransTypeCode(), "transTypeCode", result);
        getStringBuilderPack(wmsMoveMaster, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单明细表分页查询
     *
     * @param wmsMoveDetails
     * @return
     */
    public static String packHqlWmsMoveDetails(WmsMoveDetails wmsMoveDetails) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveDetails.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsMoveDetails.getPartNameRdd(), "partNameRdd", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getCustNo(), "custNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getUnit(), "unit", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getSrcWhNo(), "srcWhNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getDestWhNo(), "destWhNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getSrcZoneNo(), "srcZoneNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getDestZoneNo(), "destZoneNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getSrcLocateNo(), "srcLocateNo", result);
        HqlPack.getStringEqualPack(wmsMoveDetails.getDestLocateNo(), "destLocateNo", result);
        HqlPack.getNumEqualPack(wmsMoveDetails.getItemStatus(), "itemStatus", result);
        HqlPack.getNumEqualPack(wmsMoveDetails.getRefType(), "refType", result);
        HqlPack.getStringLikerPack(wmsMoveDetails.getRefSrc(), "refSrc", result);

        getStringBuilderPack(wmsMoveDetails, result);

        return result.toString();
    }

    /**
     * 内部单据：库存移动单条码信息分页查询
     *
     * @param wmsMoveSn
     * @return
     */
    public static String packHqlWmsMoveSn(WmsMoveSn wmsMoveSn) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveSn.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsMoveSn.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsMoveSn.getPartNameRdd(), "partNameRdd", result);

        getStringBuilderPack(wmsMoveSn, result);

        return result.toString();
    }

    /**
     * 质检单信息 查询条件封装
     *
     * @param wmsQCMaster
     * @return
     */
    public static String packHqlWmsQCMaster(WmsQCMaster wmsQCMaster) {
        StringBuffer result = new StringBuffer();

        //单号
        HqlPack.getStringEqualPack(wmsQCMaster.getOrderNo(), "orderNo", result);
        //业务类型
        HqlPack.getNumEqualPack(wmsQCMaster.getOrderType(), "orderType", result);
        //关联单据类型
        HqlPack.getStringEqualPack(wmsQCMaster.getRefType(), "refType", result);
        //关联单据号
        HqlPack.getStringEqualPack(wmsQCMaster.getRefSrc(), "refSrc", result);
        //入库单号
        HqlPack.getStringEqualPack(wmsQCMaster.getIbNo(), "ibNo", result);

        getStringBuilderPack(wmsQCMaster, result);

        return result.toString();
    }

    /**
     * 散件质检单信息 查询条件封装
     *
     * @param wmsQCMaster
     * @return
     */
    public static String packHqlWmsQCMasterPart(WmsQCMaster wmsQCMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getInPack(String.join(",", WmsEnumUtil.QC_INFO_STATUS.CREATE.getValue() + "",
                WmsEnumUtil.QC_INFO_STATUS.FINISH.getValue() + ""), "orderStatus", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue(), "isPart", result);
        //单号
        HqlPack.getStringEqualPack(wmsQCMaster.getOrderNo(), "orderNo", result);
        getStringBuilderPack(wmsQCMaster, result);

        return result.toString();
    }

    /**
     * 库存条码开窗 查询条件封装
     *
     * @param wmsStockSn
     * @return
     */
    public static String packHqlWmsStockSnDialog(WmsStockSn wmsStockSn) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getNotInPack(String.join(",", WmsEnumUtil.STOCK_SN_STATUS.CREATE.getValue() + "",
                WmsEnumUtil.STOCK_SN_STATUS.QUALITY_CONTROL.getValue() + ""), "snStatus", result);
        //单号
        HqlPack.getStringLeftLikerPack(wmsStockSn.getSn(),"sn", result);
        HqlPack.getStringEqualPack(wmsStockSn.getDateCode(),"dateCode",result);
        getStringBuilderPack(wmsStockSn, result);

        return result.toString();
    }

    /**
     * 质检单明细信息 查询条件封装
     *
     * @param wmsQCDetails
     * @return
     */
    public static String packHqlWmsQCDetails(WmsQCDetails wmsQCDetails) {
        StringBuffer result = new StringBuffer();

        //单号
        HqlPack.getStringEqualPack(wmsQCDetails.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsQCDetails, result);

        return result.toString();
    }

    /**
     * 质检单操作明细信息 查询条件封装
     *
     * @param wmsQCTrans
     * @return
     */
    public static String packHqlWmsQCTrans(WmsQCTrans wmsQCTrans) {
        StringBuffer result = new StringBuffer();
        //单号
        HqlPack.getStringEqualPack(wmsQCTrans.getOrderNo(), "orderNo", result);
        //物料
        HqlPack.getStringEqualPack(wmsQCTrans.getPartNo(), "partNo", result);

        getStringBuilderPack(wmsQCTrans, result);

        return result.toString();
    }

    /**
     * 盘点单主表信息 分页查询
     *
     * @param wmsCSOrderMaster
     * @return
     */
    public static String packHqlWmsCSOrderMasters(WmsCSOrderMaster wmsCSOrderMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsCSOrderMaster.getOrderNo(), "orderNo", result);
        HqlPack.getNumEqualPack(wmsCSOrderMaster.getOrderType(), "orderType", result);
        HqlPack.getNumEqualPack(wmsCSOrderMaster.getOrderStatus(), "orderStatus", result);
        HqlPack.getNumEqualPack(wmsCSOrderMaster.getIsPart(), "isPart", result);

        getStringBuilderPack(wmsCSOrderMaster, result);

        return result.toString();
    }

    /**
     * 盘点单冻结表信息 分页查询
     *
     * @param wmsCSOrderDetails
     * @return
     */
    public static String packHqlWmsCSOrderDetails(WmsCSOrderDetails wmsCSOrderDetails) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsCSOrderDetails.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsCSOrderDetails, result);

        return result.toString();
    }

    /**
     * 盘点实盘表信息 分页查询
     *
     * @param wmsCSFactTrans
     * @return
     */
    public static String packHqlWmsCSFactTrans(WmsCSFactTrans wmsCSFactTrans) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringEqualPack(wmsCSFactTrans.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsCSFactTrans.getPartNo(), "partNo", result);

        getStringBuilderPack(wmsCSFactTrans, result);

        return result.toString();
    }

    /**
     * 作业步骤 查询
     *
     * @param wmsActionStepCall
     * @return
     */
    public static DdlPackBean packHqlWmsActionStepCall(WmsActionStepCall wmsActionStepCall) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getNumEqualPack(wmsActionStepCall.getAsId(), "asId", result);
        DdlPreparedPack.getNumEqualPack(wmsActionStepCall.getAmId(), "amId", result);
        DdlPreparedPack.getNumEqualPack(wmsActionStepCall.getAmType(), "amType", result);

        getStringBuilderPack(wmsActionStepCall, result);

        DdlPreparedPack.getOrderByPack(new Object[]{1}, new String[]{"seq"}, result);

        return result;
    }

    /**
     * 作业步骤类型表信息查询
     *
     * @param wmsActionStepType
     * @return
     */
    public static DdlPackBean packHqlWmsActionStepType(WmsActionStepType wmsActionStepType) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getStringEqualPack(wmsActionStepType.getAtNameC(), "atNameC", result);

        getStringBuilderPack(wmsActionStepType, result);

        return result;
    }

    /**
     * 作业步骤信息查询
     *
     * @param wmsActionStep
     * @return
     */
    public static DdlPackBean packHqlWmsActionStep(WmsActionStep wmsActionStep) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getStringEqualPack(wmsActionStep.getAsNameC(), "asNameC", result);

        getStringBuilderPack(wmsActionStep, result);

        return result;
    }

    /**
     * 作业步骤处理组件查询条件封装
     *
     * @param wmsActionModuleParam
     * @return
     */
    public static DdlPackBean packHqlWmsActionModuleParam(WmsActionModuleParam wmsActionModuleParam) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getNumEqualPack(wmsActionModuleParam.getAmID(), "amID", result);
        DdlPreparedPack.getNumNOEqualPack(wmsActionModuleParam.getParamType(), "paramType", result);
        getStringBuilderPack(wmsActionModuleParam, result);
        return result;
    }

    /**
     * 作业步骤处理组件参数查询条件封装
     *
     * @param wmsActionModule
     * @return
     */
    public static DdlPackBean packHqlWmsActionModule(WmsActionModule wmsActionModule) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getStringLikerPack(wmsActionModule.getAmName(), "amName", result);
        DdlPreparedPack.getNumEqualPack(wmsActionModule.getId(), "id", result);
        DdlPreparedPack.getNumEqualPack(wmsActionModule.getAmType(), "amType", result);

        getStringBuilderPack(wmsActionModule, result);

        return result;
    }

    /**
     * 作业流程分页查询
     * @return
     */
    public static DdlPackBean packHqlWmsActionGroup(WmsActionGroup wmsActionGroup) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装 agDescC;agNameC
        DdlPreparedPack.getStringLikerPack(wmsActionGroup.getAgNameC(), "agNameC", result);
        DdlPreparedPack.getStringLikerPack(wmsActionGroup.getAgDescC(), "agDescC", result);
        getStringBuilderPack(wmsActionGroup, result);

        DdlPreparedPack.getOrderByPack(new Object[]{1}, new String[]{"createDatetime"}, result);

        return result;
    }

    /**
     * 作业流程明细分页查询
     * @return
     */
    public static DdlPackBean packHqlWmsActionGroupDetails(WmsActionGroupDetails wmsActionGroupDetails) {
        DdlPackBean result = new DdlPackBean();

        //查询参数封装
        DdlPreparedPack.getNumEqualPack(wmsActionGroupDetails.getAgId(), "agId", result);

        getStringBuilderPack(wmsActionGroupDetails, result);

        DdlPreparedPack.getOrderByPack(new Object[]{1}, new String[]{"seq"}, result);

        return result;
    }


    /**
     * 作业步骤调用参数信息 查询条件封装
     *
     * @param wmsActionStepCallParam
     * @return
     */
    public static DdlPackBean packHqlWmsActionStepCallParam(WmsActionStepCallParam wmsActionStepCallParam) {
        DdlPackBean result = new DdlPackBean();

        DdlPreparedPack.getNumEqualPack(wmsActionStepCallParam.getAgdId(), "agdId", result);
        DdlPreparedPack.getNumEqualPack(wmsActionStepCallParam.getAmId(), "amId", result);
        DdlPreparedPack.getNumEqualPack(wmsActionStepCallParam.getSeq(), "seq", result);
        getStringBuilderPack(wmsActionStepCallParam, result);

        return result;
    }

    /**
     * PO订单条码表 分页查询
     *
     * @param wmsPoSn
     * @return
     */
    public static String packHqlWmsPoSn(WmsPoSn wmsPoSn) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getStringLikerPack(wmsPoSn.getOrderNo(), "orderNo", result);
        HqlPack.getStringLikerPack(wmsPoSn.getPartNo(), "partNo", result);
        HqlPack.getStringLikerPack(wmsPoSn.getPartNameRdd(), "partNameRdd", result);

        getStringBuilderPack(wmsPoSn, result);

        return result.toString();
    }

    /**
     * 按moveNo 取最后一笔插入的数据
     *
     * @param wmsMoveSn
     * @return
     */
    public static String packHqlLastWmsMoveSn(WmsMoveSn wmsMoveSn) {
        StringBuffer result = new StringBuffer();

        HqlPack.getStringEqualPack(wmsMoveSn.getOrderNo(), "orderNo", result);
        getStringBuilderPack(wmsMoveSn, result);
        HqlPack.getOrderByPack(new Object[]{2}, new String[]{"createDatetime"}, result);

        return result.toString();
    }

    /**
     * 根据条件查询库存条码信息
     *
     * @param wmsStockSn
     * @return
     */
    public static String packHqlWmsStockSn(WmsStockSn wmsStockSn) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(wmsStockSn.getSn(), "sn", result);
        HqlPack.getStringEqualPack(wmsStockSn.getVendorNo(), "vendorNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsStockSn.getLocateNo(), "locateNo", result);
        HqlPack.getNumEqualPack(wmsStockSn.getSnStatus(), "snStatus", result);
        HqlPack.getNumEqualPack(wmsStockSn.getQcStatus(), "qcStatus", result);
        HqlPack.getStringEqualPack(wmsStockSn.getRefSrc(), "refSrc", result);
        HqlPack.getNumEqualPack(wmsStockSn.getPrinted(), "printed", result);
        getStringBuilderPack(wmsStockSn, result);
        return result.toString();
    }

    /**
     * 根据条件查询条码条码信息
     *
     * @param wmsSnPrintRcd
     * @return
     */
    public static String packHqlWmsSnPrintRcd(WmsSnPrintRcd wmsSnPrintRcd) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(wmsSnPrintRcd.getSn(), "sn", result);
        HqlPack.getStringEqualPack(wmsSnPrintRcd.getZoneNo(), "zoneNo", result);
        HqlPack.getStringEqualPack(wmsSnPrintRcd.getWhNo(), "whNo", result);
        HqlPack.getStringEqualPack(wmsSnPrintRcd.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsSnPrintRcd.getLocateNo(), "locateNo", result);
        getStringBuilderPack(wmsSnPrintRcd, result);
        return result.toString();
    }

    /**
     * 根据条件模糊查询库存条码信息
     *
     * @param wmsStockSn
     * @return
     */
    public static String packHqlWmsStockSnLike(WmsStockSn wmsStockSn) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringRightLikerPack(wmsStockSn.getSn(), "sn", result);
        getStringBuilderPack(wmsStockSn, result);
        HqlPack.getOrderByPack(new Object[]{2}, new String[]{"createDatetime"}, result);
        return result.toString();
    }

    /**
     * 根据条件查询库存信息
     *
     * @param wmsStockQuan
     * @return
     */
    public static String packHqlWmsStockQuan(WmsStockQuan wmsStockQuan) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(wmsStockQuan.getPartNo(), "partNo", result);
        HqlPack.getStringEqualPack(wmsStockQuan.getLocateNo(), "locateNo", result);
        getStringBuilderPack(wmsStockQuan, result);
        return result.toString();
    }

    /**
     * 根据用户角色id列表查询数据权限信息
     *
     * @return
     */
    public static String packHqlWmsDataAuth(WmsDataAuth dataAuth, List<String> roleIds) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(dataAuth.getDataObj(), "dataObj", result);
        String data = String.join(",", roleIds);
        HqlPack.getInPackString(data, "roleCode", result);
        getStringBuilderPack(new WmsDataAuth(), result);
        return result.toString();
    }

    /**
     * 根据权限数据拼查询任务详情sql
     *
     * @param groupDataAuth
     * @return
     */
    public static String packHqlWmsTaskDetail(Map<String, List<WmsDataAuth>> groupDataAuth) {
        StringBuffer result = new StringBuffer();
        Set<Map.Entry<String, List<WmsDataAuth>>> entries = groupDataAuth.entrySet();
        //拼sql
        entries.stream().filter(o -> !Strings.isNullOrEmpty(o.getKey())).forEach(o -> {
            List<WmsDataAuth> value = o.getValue();
            List<String> vList = value.stream().map(x -> x.getDataObjValue()).collect(Collectors.toList());
            String data = String.join(",", vList);
            if (StringUtils.isNotBlank(data)) {
                List<Map> mapList = JSONObject.parseArray(data, Map.class);
                if (StringUtils.equalsIgnoreCase(WmsEnumUtil.DATA_OBJ_TYPE.WAREHOUSE.getValue() + "", o.getKey())) {
                    for (Map whNoItem : mapList) {
                        HqlPack.getInOrPackString(whNoItem.get("WH_CODE").toString(), "destWhNo", result);
                    }
                } else if (StringUtils.equalsIgnoreCase(WmsEnumUtil.DATA_OBJ_TYPE.LOCATE.getValue() + "", o.getKey())) {
                    for (Map locateNoItem : mapList) {
                        HqlPack.getInOrPackString(locateNoItem.get("LOCATE_NO").toString(), "destLocateNo", result);
                    }
                } else if (StringUtils.equalsIgnoreCase(WmsEnumUtil.DATA_OBJ_TYPE.ZONE.getValue() + "", o.getKey())) {
                    for (Map zoneNoItem : mapList) {
                        HqlPack.getInOrPackString(zoneNoItem.get("ZONE_CODE").toString(), "destZoneNo", result);
                    }
                } else if (StringUtils.equalsIgnoreCase(WmsEnumUtil.DATA_OBJ_TYPE.MATERIAL.getValue() + "", o.getKey())) {
                    for (Map zoneNoItem : mapList) {
                        HqlPack.getInOrPackString(zoneNoItem.get("PART_NO").toString(), "partNo", result);
                    }
                }
            }
        });
        getStringBuilderPack(new WmsDataAuth(), result);
        return result.toString();
    }

    /**
     * 给定字段动态in sql
     *
     * @param columnName
     * @param vals
     * @return
     */
    public static String packHqlAndIn(WmsTaskInfo bean, String columnName, List<String> vals) {
        StringBuffer result = new StringBuffer();
        String data = String.join(",", vals);
        HqlPack.getInPackString(data, columnName, result);
        HqlPack.getStringRightLikerPack(bean.getOrderNo(), "orderNo", result);
        HqlPack.getNumNOEqualPack(bean.getTaskStatus(), "taskStatus", result);
        getStringBuilderPack(bean, result);
        return result.toString();
    }

    /**
     * 根据条件查询dataAuth
     *
     * @param wmsDataAuth
     * @return
     */
    public static String packHqlWmsDataAuthFind(WmsDataAuth wmsDataAuth) {
        StringBuffer result = new StringBuffer();
        if (!Strings.isNullOrEmpty(wmsDataAuth.getRoleCode())) {
            HqlPack.getStringEqualPack(wmsDataAuth.getRoleCode(), "roleCode", result);
        }
        if (!Strings.isNullOrEmpty(wmsDataAuth.getDataObj())) {
            HqlPack.getStringEqualPack(wmsDataAuth.getDataObj(), "dataObj", result);
        }
        if (!Strings.isNullOrEmpty(wmsDataAuth.getDataObjValue())) {
            HqlPack.getStringRightLikerPack(wmsDataAuth.getDataObjValue(), "dataObjValue", result);
        }
        getStringBuilderPack(wmsDataAuth, result);
        return result.toString();
    }

    /**
     * 根据条件查询任务明细信息
     *
     * @param taskDetails
     * @return
     */
    public static String packHqlWmsTaskDetails(WmsTaskDetails taskDetails) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(taskDetails.getOrderNo(), "orderNo", result);
        getStringBuilderPack(taskDetails, result);
        return result.toString();
    }

    /**
     * 根据条件查询任务生成日志
     *
     * @param wmsTaskCreateLog
     * @return
     */
    public static String packHqlWmsTaskCreateLog(WmsTaskCreateLog wmsTaskCreateLog) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(wmsTaskCreateLog.getTaskNo(), "taskNo", result);
        HqlPack.getStringEqualPack(wmsTaskCreateLog.getOpTypeCode(), "opTypeCode", result);
        getStringBuilderPack(wmsTaskCreateLog, result);
        return result.toString();
    }

    /**
     * 根据条件查询作业处理组件
     *
     * @param wmsTransModule
     * @return
     */
    public static String packHqlWmsTransModule(WmsTransModule wmsTransModule) {
        StringBuffer result = new StringBuffer();
        if (!Strings.isNullOrEmpty(wmsTransModule.getTmName())) {
            HqlPack.getStringEqualPack(wmsTransModule.getTmName(), "tmName", result);
        }
        if (!Strings.isNullOrEmpty(wmsTransModule.getCallClass())) {
            HqlPack.getStringEqualPack(wmsTransModule.getCallClass(), "callClass", result);
        }
        if (!Strings.isNullOrEmpty(wmsTransModule.getTmDesc())) {
            HqlPack.getStringLikerPack(wmsTransModule.getTmDesc(), "tmDesc", result);
        }
        getStringBuilderPack(wmsTransModule, result);
        return result.toString();
    }

    /**
     * 根据条件查询系统配置信息
     *
     * @param wmsConfig
     * @return
     */
    public static String packHqlWmsConfig(WmsConfig wmsConfig) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(wmsConfig.getConfigCode(), "configCode", result);
        getStringBuilderPack(wmsConfig, result);
        return result.toString();
    }

    /**
     * 移库单订单条码表 分页查询
     *
     * @param wmsDocMovementSn
     * @return
     */
    public static String packHqlWmsDocMovementSn(WmsDocMovementSn wmsDocMovementSn) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(wmsDocMovementSn.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(wmsDocMovementSn.getPartNo(), "partNo", result);

        getStringBuilderPack(wmsDocMovementSn, result);

        return result.toString();
    }

    /**
     * 移库单订单条码表 分页查询
     *
     * @param details
     * @return
     */
    public static String packHqlWmsDocMovementDetails(WmsDocMovementDetails details) {
        StringBuffer result = new StringBuffer();
        HqlPack.getStringEqualPack(details.getOrderNo(), "orderNo", result);
        HqlPack.getStringEqualPack(details.getPartNo(), "partNo", result);

        getStringBuilderPack(details, result);

        return result.toString();
    }

    /**
     * 查询脚本持久化 查询条件封装
     * @return
     */
    public static DdlPackBean packEngineScriptPersistence(EngineScriptPersistence scriptPersistence) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(scriptPersistence.getScriptNo(), "scriptNo", packBean);
        DdlPreparedPack.getStringRightLikerPack(scriptPersistence.getScriptName(), "scriptName", packBean);
        DdlPreparedPack.getNumEqualPack(scriptPersistence.getScriptType(), "scriptType", packBean);
        DdlPreparedPack.getNumEqualPack(scriptPersistence.getLanguageType(), "languageType", packBean);

        getStringBuilderPack(scriptPersistence, packBean);

        DdlPreparedPack.getOrderByPack(new Object[]{2}, new String[]{"createDatetime"}, packBean);
        return packBean;
    }

    /**
     * 盘点主表 分页查询(散件)
     *
     * @param wmsCSOrderMaster
     * @return
     */
    public static String packHqlWmsCSOrderMasterPart(WmsCSOrderMaster wmsCSOrderMaster) {
        StringBuffer result = new StringBuffer();

        //查询参数封装
        HqlPack.getInPack(String.join(",", WmsEnumUtil.CS_ORDER_STATUS.STARTING_INVENTORY.getValue() + "",
                WmsEnumUtil.CS_ORDER_STATUS.IN_INVENTORY.getValue() + ""), "orderStatus", result);
        HqlPack.getNumEqualPack(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue(), "isPart", result);
        HqlPack.getStringEqualPack(wmsCSOrderMaster.getOrderNo(), "orderNo", result);

        getStringBuilderPack(wmsCSOrderMaster, result);

        return result.toString();
    }
}
